@@ -50,7 +50,7 @@ class DataLogger:
 
     Methods
     -------
-    connect(server, login="", password="", certificate="mcx.cert.pem")
+    connect(server, login="", password="", certificate="mcx.cert.crt")
         connects to a server
     openFileAndWriteHeader(filename)
         opens a file and writes the header information to that file
@@ -90,7 +90,7 @@ class DataLogger:
         if self.connected:
             self.__initTraces(paths)
 
-    def connect(self, url, login, password, certificate="mcx.cert.pem", conn_timeout_ms=1000):
+    def connect(self, url, login, password, certificate="mcx.cert.crt", conn_timeout_ms=1000):
         """
         Connect to a Motorcortex server and login
 
@@ -174,9 +174,11 @@ class DataLogger:
         Open a file an write the header containing column names for each signal
         """
         if compress:
-            self.file = lzma.open(filename+'.xz', 'wt', preset=0)
+            filename = filename + '.xz'
+            self.file = lzma.open(filename, 'wt', preset=0)
         else:
             self.file = open(filename, 'w', buffering=1)
+        print("Writing to %s"%filename)
         self.file.write("time")
         returnVal = True
         for path in self.paths:
